/* Robustness exercices
 We perform four exercises using the data on Indonesia:
1. We replicate the analysis using ethnic instead of religious shares: Appendix Figure 6
2. We check the validity of the results using only data from 1971, 1980 and 1990. The rationale for this check is that the number of regencies has increased vastly after 1998: Appendix Figure 7
3. We look at the difference between intensive and extensive margins of fertility: Appendix Figure 8
4. We check the results on the rural and urban samples separately: Appendix Figure 9
*/

*************************************************************************************
* Appendix Figure 6: Fertility and education choices by ethnic group size Indonesia *
*************************************************************************************

* 1a. Fertility

use "${pathdata}\Indonesia_ethnic.dta", clear

preserve
keep if ethnic_sh!=.&f_selec==1
xtile ethnic_sh_dec_f= ethnic_sh, nq(10) 	// create a categorical variable for the deciles of ethnic_sh for fertility sample
xtile ethnic_sh_ven_f= ethnic_sh, nq(20)		// create a categorical variable for the ventiles of ethnic_sh
* gen categories based on deciles, with first decile divided in 2 ventiles
gen ethnic_sh_dec_11_f=ethnic_sh_ven_f-1 if ethnic_sh_ven_f<3
replace ethnic_sh_dec_11_f=ethnic_sh_dec_f if ethnic_sh_dec_f>1

cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values ethnic_sh_dec_11_f eleveniles

global controls1 "i.birthyr i.urban"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"

global exp_vard "ethnic_sh_dec_11_f"
global exp_var "ib9.ethnic_sh_dec_11_f"


foreach i in chborn chsurv {
eststo clear
eststo: poisson `i' $exp_var $controls1 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: poisson `i' $exp_var $controls1 $controls2  if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3  if f_selec ==1&mig==1, vce(cluster geo2_id)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure6_`i'.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure6_`i'.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}
cap restore

* 1b. Education

keep if ethnic_sh!=.&e_selec!=.

xtile ethnic_sh_dec_e3= ethnic_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of rel_sh for education sample

xtile ethnic_sh_ven_e3= ethnic_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of rel_sh for education sample

* gen categories based on deciles, with first decile divided in 2 ventiles

gen ethnic_sh_dec_11_e3=ethnic_sh_ven_e3-1 if ethnic_sh_ven_e3<3
replace ethnic_sh_dec_11_e3=ethnic_sh_dec_e3 if ethnic_sh_dec_e3>1 


cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values ethnic_sh_dec_11_e* eleveniles

tab ethnic_sh_dec_11_e3

global controls1 "i.birthyr  i.urban"
global controls2 "c.iinfmort"
global controls3 "ib5000.religiond i.sex"

global exp_vard "ethnic_sh_dec_11_e3"
global exp_var "ib9.ethnic_sh_dec_11_e3"
eststo clear
eststo: reg yrschool ${exp_var} $controls1 if e_selec ==3, vce(cluster geo2_id)
estimates store tool1
margins i.$exp_vard, post
estimates store pred1
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3, vce(cluster geo2_id)
estimates store tool2
margins i.$exp_vard, post
estimates store pred2
eststo: reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geo2_id)
estimates store tool3
margins i.$exp_vard, post
estimates store pred3
eststo: reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3&mig==1, vce(cluster geo2_id)
estimates store tool4
margins i.$exp_vard, post
estimates store pred4
coefplot (pred1, label(model 1)) (pred2, label(model 2)) (pred3, label(model 3)) (pred4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure6_educ.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure6_educ.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) 
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" \(R^{2}\)"' ))
drop _est_tool*


*************************************************************************************************************
* Appendix Figure 7: Fertility and education choices by religious group size Indonesia - sample before 2000 *
*************************************************************************************************************

use "${pathdata}\Indonesia_analysis.dta", clear


** 2a. YEAR<2000 - FERTILITY

preserve
keep if f_selec!=.&year<2000

global controls1 "i.birthyr i.urban##i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"


global exp_vard "rel_sh_dec_11_f"
global exp_var "ib9.rel_sh_dec_11_f"


foreach i in chborn chsurv {
eststo clear
eststo: poisson `i' $exp_var $controls1 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: poisson `i' $exp_var $controls1 $controls2  if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3  if f_selec ==1&mig==1, vce(cluster geo2_id)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure7_`i'.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure7_`i'.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}
restore

** 2b. YEAR<2000 - EDUCATION

 preserve
keep if e_selec!=.&year<2000

global controls1 "i.birthyr  i.urban##i.year"
global controls2 "c.iinfmort"
global controls3 "ib5000.religiond i.sex"


global exp_vard "rel_sh_dec_11_e3"
global exp_var "ib19.rel_sh_dec_11_e3"
eststo clear
eststo: reg yrschool $exp_var $controls1 if e_selec ==3, vce(cluster geo2_id)
estimates store tool1
margins i.$exp_vard, post
estimates store pred1
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3, vce(cluster geo2_id)
estimates store tool2
margins i.$exp_vard, post
estimates store pred2
eststo: reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geo2_id)
estimates store tool3
margins i.$exp_vard, post
estimates store pred3
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3&mig==1, vce(cluster geo2_id)
estimates store tool4
margins i.$exp_vard, post
estimates store pred4
coefplot (pred1, label(model 1)) (pred2, label(model 2)) (pred3, label(model 3)) (pred4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure7_education.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure7_education.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" \(R^{2}\)"' ))
drop _est_tool*



*************************************************************************************************************************
* Appendix Figure 8: Fertility and education choices by religious group size Indonesia - intensive vs extensive margins *
*************************************************************************************************************************

use "${pathdata}\Indonesia_analysis.dta", clear

** 3a. Extensive margin - FERTILITY

preserve
keep if f_selec!=.
 
global controls1 "i.birthyr i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"


global exp_vard "rel_sh_dec_11_f"
global exp_var "ib9.rel_sh_dec_11_f"

gen chless=.
foreach i in chborn chsurv {
	replace chless=(`i'==0)
eststo clear
eststo: reg chless $exp_var $controls1 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: reg chless $exp_var $controls1 $controls2  if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: reg chless $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geo2_id)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: reg chless $exp_var $controls1 $controls2 $controls3  if f_selec ==1&mig==1, vce(cluster geo2_id)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure8_`i'_extensive.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure8_`i'_extensive.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}

** 3b. Intensive margin - FERTILITY


foreach i in chborn chsurv {
eststo clear
eststo: poisson `i' $exp_var $controls1 if f_selec ==1&`i'>0, vce(cluster geo2_id)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: poisson `i' $exp_var $controls1 $controls2  if f_selec ==1&`i'>0, vce(cluster geo2_id)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3 if f_selec ==1&`i'>0, vce(cluster geo2_id)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3  if f_selec ==1&`i'>0&mig==1, vce(cluster geo2_id)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure8_`i'_intensive.png.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure8_`i'_intensive.png.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}

restore

*****************************************************************************************************************
* Appendix Figure 9: Fertility and education choices by religious group size Indonesia - urban vs rural samples *
*****************************************************************************************************************

use "${pathdata}\Indonesia_analysis.dta", clear

** 4a. URBAN vs RURAL - FERTILITY

preserve
keep if f_selec!=.
 
global controls1 "i.birthyr i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"

global exp_vard "rel_sh_dec_11_f"
global exp_var "ib9.rel_sh_dec_11_f"

forvalue j=1/2 {
foreach i in chborn chsurv {
eststo clear
eststo: poisson `i' $exp_var $controls1 if f_selec ==1&urban==`j', vce(cluster geo2_id)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: poisson `i' $exp_var $controls1 $controls2  if f_selec ==1&urban==`j', vce(cluster geo2_id)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3 if f_selec ==1&urban==`j', vce(cluster geo2_id)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3  if f_selec ==1&urban==`j'&mig==1, vce(cluster geo2_id)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure9_`i'_`j'.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure9_`i'_`j'.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}
}
restore

** 4b. RURAL vs URBAN - EDUCATION

 preserve
keep if e_selec!=.

global controls1 "i.birthyr  i.year"
global controls2 "c.iinfmort"
global controls3 "ib5000.religiond i.sex"

forvalue i=1/2 {
global exp_vard "rel_sh_dec_11_e3"
global exp_var "ib19.rel_sh_dec_11_e3"
eststo clear
eststo: reg yrschool $exp_var $controls1 if e_selec ==3&urban==`i', vce(cluster geo2_id)
estimates store tool1
margins i.$exp_vard, post
estimates store pred1
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3&urban==`i', vce(cluster geo2_id)
estimates store tool2
margins i.$exp_vard, post
estimates store pred2
eststo: reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3&urban==`i', vce(cluster geo2_id)
estimates store tool3
margins i.$exp_vard, post
estimates store pred3
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3&urban==`i'&mig==1, vce(cluster geo2_id)
estimates store tool4
margins i.$exp_vard, post
estimates store pred4
coefplot (pred1, label(model 1)) (pred2, label(model 2)) (pred3, label(model 3)) (pred4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(cols(4))
graph export "${path}\Output\App_Figure9_educ_`i'.png", as(png) replace
esttab coef* using "${path}\Output\App_Figure9_educ_`i'.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" \(R^{2}\)"' ))
drop _est_tool*
}

restore